@@ -164,7 +164,7 @@ clean_wd <- function (path) {
 #'
 #'   | No.  | Column        | Type        | Description                                                      |
 #'   | ---: | -----         | -----       | -----                                                            |
-#'   | 1    | `index`       | `integer`   | Index of simuation                                               |
+#'   | 1    | `index`       | `integer`   | Index of simulation                                              |
 #'   | 2    | `status`      | `character` | Simulation status                                                |
 #'   | 3    | `idf`         | `character` | Full path of input IDF file                                      |
 #'   | 4    | `epw`         | `character` | Full path of input EPW file. `NA` for design-day-only simulation |
@@ -256,7 +256,11 @@ run_idf <- function (model, weather, output_dir, design_day = FALSE,
     # clean wd
     clean_wd(loc_m)
 
-    res <- energyplus(energyplus_exe, loc_m, loc_w, output_dir = output_dir,
+    # Let energyplus commandline interface itself to handle output file
+    # directory. This is the easiest way to external file dependencies, instead
+    # of doing it on the R side.
+    # See #344
+    res <- energyplus(energyplus_exe, model, weather, output_dir = output_dir,
         annual = annual, design_day = design_day, expand_obj = expand_obj,
         wait = wait, echo = echo)
 
@@ -274,11 +278,12 @@ run_idf <- function (model, weather, output_dir, design_day = FALSE,
 #' @rdname run_model
 # run_multi {{{
 run_multi <- function (model, weather, output_dir, design_day = FALSE,
-                       annual = FALSE, wait = TRUE, echo = TRUE, eplus = NULL) {
+                       annual = FALSE, expand_obj = TRUE, wait = TRUE, echo = TRUE, eplus = NULL) {
     assert_flag(wait)
     assert_flag(echo)
     assert_logical(design_day, any.missing = FALSE)
     assert_logical(annual, any.missing = FALSE)
+    assert_logical(expand_obj, any.missing = FALSE)
 
     if (length(model) != 1L) {
         if (!is.null(weather) && length(weather) != 1L) {
@@ -293,6 +298,9 @@ run_multi <- function (model, weather, output_dir, design_day = FALSE,
         if (length(annual) != 1L) {
             assert_same_len(model, annual)
         }
+        if (length(expand_obj) != 1L) {
+            assert_same_len(model, expand_obj)
+        }
     }
 
     if (any(annual & design_day)) {
@@ -364,7 +372,7 @@ run_multi <- function (model, weather, output_dir, design_day = FALSE,
     jobs[, `:=`(
         energyplus = energyplus_exe,
         model = copy_run_files(model, output_dir), version = ver,
-        index = .I, annual = annual, design_day = design_day
+        index = .I, annual = annual, design_day = design_day, expand_obj = expand_obj
     )]
 
     if (is.null(weather)) {
@@ -501,7 +509,8 @@ run_job <- function(jobs, options, progress_bar) {
 
         process <- energyplus(eplus = energyplus, model = model,
             weather = unlist(weather), output_dir = output_dir, annual = annual,
-            design_day = design_day, wait = FALSE, echo = FALSE)$process
+            design_day = design_day, wait = FALSE, echo = FALSE,
+            expand_obj = expand_obj)$process
 
         if (options$echo) {
             run <- sim_status("run", index_str, model, weather)
@@ -705,8 +714,8 @@ energyplus <- function (eplus, model, weather, output_dir, output_prefix = NULL,
         model <- model_ori
         # _exp.idf --> .expidf
         rename_exp <- function () {
-            path <- paste0(stri_sub(tools::file_path_sans_ext(model_exp), to = -5L), ".expidf")
-            try(file.rename(model_exp, path), silent = TRUE)
+            path <- basename(paste0(stri_sub(tools::file_path_sans_ext(model_exp), to = -5L), ".expidf"))
+            try(file.rename(model_exp, file.path(output_dir, path)), silent = TRUE)
         }
     }
 
@@ -912,6 +921,12 @@ expand_objects <- function (eplus, idf, keep_ext = FALSE) {
     unlink(file.path(dirname(idf), "in.idf"), force  = TRUE)
     unlink(file.path(dirname(idf), "expandedidf.err"), force  = TRUE)
     unlink(file.path(dirname(idf), "fort.6"), force  = TRUE)
-    if (file.exists(out)) setattr(out, "expanded", expanded) else setattr(idf, "expanded", expanded)
+    if (file.exists(out)) {
+        attr(out, "expanded") <- expanded
+        out
+    } else {
+        attr(idf, "expanded") <- expanded
+        idf
+    }
 }
 # }}}
