@@ -1,11 +1,9 @@
-context("Format methods")
-
 test_that("Formatting", {
     # only test on UTF-8 supported platform
     skip_if_not(cli::is_utf8_output())
 
     # IDD {{{
-    idd_parsed <- parse_idd_file(text("idd", "9.9.9"))
+    idd_parsed <- parse_idd_file(idftext("idd", "9.9.9"))
 
     expect_equal(format_name(idd_parsed$field),
         c("!- Test Field",
@@ -232,7 +230,7 @@ test_that("Formatting", {
     expect_equal(format_header(view_in_ip = TRUE)[2], "!-Option SortedOrder ViewInIPunits")
 
     idd_parsed <- get_priv_env(use_idd(8.8, "auto"))$m_idd_env
-    idf_parsed <- parse_idf_file(text("idf", "8.8"))
+    idf_parsed <- parse_idf_file(idftext("idf", "8.8"))
     add_joined_cols(idd_parsed$field, idf_parsed$value, "field_id", c("field_index", "type_enum", "units", "ip_units"))
     # object
     expect_equal(format_objects(idf_parsed$object, component = "object")$out,
