@@ -1,12 +1,10 @@
-context("Idf class")
-
 eplusr_option(verbose_info = FALSE)
 use_idd(8.8, "auto")
 
 # NEW {{{
 test_that("$new()", {
     # can create new Idf object from string
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     priv <- get_priv_env(idf)
 
@@ -25,7 +23,7 @@ test_that("$new()", {
 
 # VERSION {{{
 test_that("$version()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     expect_equal(idf$version(), as.numeric_version("8.8.0"))
 })
@@ -33,7 +31,7 @@ test_that("$version()", {
 
 # PATH {{{
 test_that("$path()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
     expect_equal(idf$path(), NULL)
 
     expect_is(idf <- read_idf(example()), "Idf")
@@ -43,7 +41,7 @@ test_that("$path()", {
 
 # GROUP_NAME {{{
 test_that("$group_name()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can get group names in Idf
     expect_equal(idf$group_name(), c("Simulation Parameters",
@@ -65,7 +63,7 @@ test_that("$group_name()", {
 
 # CLASS_NAME {{{
 test_that("$class_name()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can get class names in Idf
     expect_equal(idf$class_name(sorted = FALSE),
@@ -96,7 +94,7 @@ test_that("$class_name()", {
 
 # OBJECT_ID {{{
 test_that("$object_id()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can get all object ids
     expect_equal(idf$object_id(),
@@ -112,7 +110,7 @@ test_that("$object_id()", {
 
 # OBJECT_NAME {{{
 test_that("$object_name()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can get object names
     expect_equal(idf$object_name(), list(Version = NA_character_, Material = c("WD01", "WD02"),
@@ -127,7 +125,7 @@ test_that("$object_name()", {
 
 # OBJECT_NUM {{{
 test_that("$object_num()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can get object num
     expect_equal(idf$object_num(), 5L)
@@ -138,7 +136,7 @@ test_that("$object_num()", {
 
 # IS_VALID_GROUP {{{
 test_that("$is_valid_group()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can check invalid group name
     expect_true(idf$is_valid_group("Simulation Parameters"))
@@ -148,7 +146,7 @@ test_that("$is_valid_group()", {
 
 # IS_VALID_CLASS {{{
 test_that("$is_valid_class()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can check invalid class name
     expect_true(idf$is_valid_class("Version"))
@@ -158,7 +156,7 @@ test_that("$is_valid_class()", {
 
 # IS_VALID_ID {{{
 test_that("$is_valid_id()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can check invalid object ID
     expect_true(idf$is_valid_id(1L))
@@ -170,7 +168,7 @@ test_that("$is_valid_id()", {
 
 # IS_VALID_NAME {{{
 test_that("$is_valid_name()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can check invalid object name
     expect_true(idf$is_valid_name("WD01"))
@@ -182,7 +180,7 @@ test_that("$is_valid_name()", {
 
 # IS_UNSAVED {{{
 test_that("$is_unsaved()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can check if model has been changed since read
     expect_false(idf$is_unsaved())
@@ -191,7 +189,7 @@ test_that("$is_unsaved()", {
 
 # DEFINITION {{{
 test_that("$definition()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can get Idd
     expect_is(idf$definition(), "Idd")
@@ -203,7 +201,7 @@ test_that("$definition()", {
 
 # OBJECT {{{
 test_that("$object()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can get IdfObject
     expect_is(idf$object(1), "IdfObject")
@@ -215,7 +213,7 @@ test_that("$object()", {
 
 # OBJECT_UNIQUE {{{
 test_that("$object_unique()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can stop if not a unique-class name
     expect_error(idf$object_unique("Material"))
@@ -237,7 +235,7 @@ test_that("$object_unique()", {
 
 # OBJECTS {{{
 test_that("$objects()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     expect_equal(names(idf$objects("WD01")), "WD01")
 
@@ -252,7 +250,7 @@ test_that("$objects()", {
 
 # OBJECTS_IN_CLASS {{{
 test_that("$objects_in_class()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can get all objects in a class
     expect_error(idf$objects_in_class("version"), class = "eplusr_error_invalid_class_name")
@@ -262,7 +260,7 @@ test_that("$objects_in_class()", {
 
 # OBJECTS_IN_GROUP {{{
 test_that("$objects_in_group()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can get all objects in a group
     expect_error(idf$objects_in_group("Schedules"), class = "eplusr_error_invalid_group_name")
@@ -273,7 +271,7 @@ test_that("$objects_in_group()", {
 # OBJECT_RELATION {{{
 test_that("$object_relation()", {
     skip_on_cran()
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
     expect_is(idf$object_relation(2), "IdfRelation")
 
     idf_1 <- read_idf(file.path(eplus_config(8.8)$dir, "ExampleFiles/5Zone_Transformer.idf"))
@@ -316,7 +314,7 @@ test_that("$object_relation()", {
 
 # OBJECTS_IN_RELATION {{{
 test_that("$objects_in_relation()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     expect_is(obj <- idf$objects_in_relation(2), "list")
     expect_equal(length(obj), 2L)
@@ -334,7 +332,7 @@ test_that("$objects_in_relation()", {
 
 # SEARCH_OBJECT {{{
 test_that("$search_object()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     expect_error(idf$search_object("W", class = rep("Version", 2)))
 
@@ -349,7 +347,7 @@ test_that("$search_object()", {
 
 # DUP {{{
 test_that("$dup()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can duplicate objects and assign new names
     expect_equal(names(idf$dup("WD01-DUP" = "WD01")), "WD01-DUP")
@@ -363,7 +361,7 @@ test_that("$dup()", {
 
 # ADD {{{
 test_that("$add()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # invalid value input format
     expect_error(idf$add("Material" = list(name = "mat"), "Construction"))
@@ -517,7 +515,7 @@ test_that("$set()", {
 
 # DEL {{{
 test_that("$del()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     expect_error(idf$del(5L), class = "eplusr_error_del_version")
     expect_error(idf$del(c(1, 2, 1)), class = "eplusr_error_del_same")
@@ -538,7 +536,7 @@ test_that("$del()", {
 
 # PURGE {{{
 test_that("$purge()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     expect_error(idf$purge(1000), class = "eplusr_error_invalid_object_id")
     expect_error(idf$purge(class = "AirLoopHVAC"), class = "eplusr_error_invalid_class_name")
@@ -559,17 +557,17 @@ test_that("$purge()", {
     expect_false(all(idf$purge(c(1, 2, 3))$is_valid_id(c(1, 2, 3))))
 
     # can purge using input class names
-    idf <- read_idf(text("idf", 8.8))
+    idf <- read_idf(idftext("idf", 8.8))
     expect_equal(idf$purge(class = "Material")$is_valid_id(c(1, 4)), c(TRUE, FALSE))
-    idf <- read_idf(text("idf", 8.8))
+    idf <- read_idf(idftext("idf", 8.8))
     expect_equal(idf$purge(class = c("Material", "Construction"))$is_valid_id(c(1, 4)), c(TRUE, FALSE))
 
     # can purge using input class names
-    idf <- read_idf(text("idf", 8.8))
+    idf <- read_idf(idftext("idf", 8.8))
     expect_equal(idf$purge(group = "Surface Construction Elements")$is_valid_id(c(1, 4)), c(TRUE, FALSE))
 
     # can purge using various specifications
-    idf <- read_idf(text("idf", 8.8))
+    idf <- read_idf(idftext("idf", 8.8))
     expect_equal(idf$purge(1:5, c("Material", "Construction"), idf$group_name())$is_valid_id(1:5), c(rep(FALSE, 4), TRUE))
 })
 # }}}
@@ -614,7 +612,7 @@ test_that("$rename()", {
 
 # INSERT {{{
 test_that("$insert()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
     expect_is(idf_full <- read_idf(example()), "Idf")
 
     expect_error(idf$insert(list()), class = "eplusr_error_dots_format")
@@ -648,7 +646,7 @@ test_that("$insert()", {
 # SEARCH_VALUE {{{
 test_that("$search_value()", {
     # can create new Idf object from string
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     expect_null(idf$search_value("AAA"))
     expect_equal(
@@ -660,7 +658,7 @@ test_that("$search_value()", {
 
 # REPLACE_VALUE {{{
 test_that("$replace_value()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     expect_equal(
         without_checking(vapply(idf$replace_value("WALL-1", "WALL-2"), function (x) x$id(), integer(1))),
@@ -685,7 +683,7 @@ test_that("$paste()", {
 
 # LOAD {{{
 test_that("$load()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can error if trying to add Version
     expect_error(idf$load("Version,8.7;\n"))
@@ -743,7 +741,7 @@ test_that("$update()", {
 
 # VALIDATE {{{
 test_that("$validate()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     expect_is(val <- idf$validate(), "IdfValidity")
     expect_equal(val$missing_object, c("Building", "GlobalGeometryRules"))
@@ -780,7 +778,7 @@ test_that("$validate()", {
 
 # IS_VALID {{{
 test_that("$is_valid()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     expect_false(idf$is_valid())
 })
@@ -815,7 +813,7 @@ test_that("$to_string()", {
 # TO_TABLE {{{
 test_that("$to_table()", {
     # can get idf in table format
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
     expect_is(idf$to_table(), "data.table")
     expect_is(idf$to_string(), "character")
     expect_equal(
@@ -1037,7 +1035,7 @@ test_that("$to_table()", {
 
 # SAVE {{{
 test_that("$save()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
     expect_error(idf$save(), "not created from local", "eplusr_error")
 
     unlink(file.path(tempdir(), "test_save.idf"), force = TRUE)
@@ -1050,7 +1048,7 @@ test_that("$save()", {
 # RUN {{{
 test_that("$run()", {
     skip_on_cran()
-    expect_error(read_idf(text("idf", 8.8))$save(), class = "eplusr_error")
+    expect_error(read_idf(idftext("idf", 8.8))$save(), class = "eplusr_error")
     expect_is(idf <- read_idf(example()), "Idf")
     expect_is(job <- idf$run(NULL, tempdir(), echo = FALSE), "EplusJob")
 
@@ -1079,8 +1077,11 @@ test_that("$geometry()", {
 # VIEW {{{
 test_that("$view()", {
     skip_on_cran()
-    expect_warning(empty_idf(8.8)$view())
-    expect_is(read_idf(example())$view(), "IdfViewer")
+    expect_warning(v <- empty_idf(8.8)$view())
+    v$close()
+
+    expect_is(v <- read_idf(example())$view(), "IdfViewer")
+    v$close()
 
     expect_is(v <- plot(read_idf(example())), "IdfViewer")
     v$close()
@@ -1099,7 +1100,7 @@ test_that("$clone()", {
 
 # PRINT {{{
 test_that("$print()", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
     expect_output(idf$print())
 
     # only test on UTF-8 supported platform
@@ -1140,20 +1141,6 @@ test_that("idf_add_output_*", {
 })
 # }}}
 
-# ACTIVE BINDING {{{
-test_that("add_idd_class_bindings", {
-    expect_is(with_option(list(autocomplete = FALSE), idf <- read_idf(example())), "Idf")
-    expect_false("Version" %in% ls(idf))
-
-    expect_is(with_option(list(autocomplete = TRUE), idf <- read_idf(example())), "Idf")
-    expect_true(all(idf$class_name() %in% ls(idf)))
-
-    expect_null(without_checking(with_option(list(autocomplete = TRUE), idf$Timestep <- NULL)))
-    expect_output(with_option(list(autocomplete = TRUE), print(idf)))
-    expect_false("Timestep" %in% ls(idf))
-})
-# }}}
-
 # EMPTY IDF {{{
 test_that("empty_idf()", {
     expect_is(idf <- empty_idf(8.8), "Idf")
@@ -1162,7 +1149,7 @@ test_that("empty_idf()", {
 
 # S3 FORMATTING {{{
 test_that("format.Idf, as.character.Idf and etc", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     expect_output(print(idf))
 
@@ -1180,8 +1167,8 @@ test_that("format.Idf, as.character.Idf and etc", {
 
 # S3 EQUALITY {{{
 test_that("==.Idf and !=.Idf", {
-    expect_is(idf_1 <- read_idf(text("idf", 8.8)), "Idf")
-    expect_is(idf_2 <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf_1 <- read_idf(idftext("idf", 8.8)), "Idf")
+    expect_is(idf_2 <- read_idf(idftext("idf", 8.8)), "Idf")
 
     # can check equality
     expect_false(idf_1 == TRUE)
@@ -1194,7 +1181,7 @@ test_that("==.Idf and !=.Idf", {
 
 # S3 SUBSET {{{
 test_that("[[.Idf and $.Idf", {
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
 
     expect_is(idf$Version, "IdfObject")
 
@@ -1212,7 +1199,7 @@ test_that("[[.Idf and $.Idf", {
 # S3 ASSIGN {{{
 test_that("[[<-.Idf and $<-.Idf", {
     skip_on_cran()
-    expect_is(idf <- read_idf(text("idf", 8.8)), "Idf")
+    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
     expect_error(idf$version() <- NULL)
     expect_error(idf$VERSION <- NULL)
     expect_error(idf[[1:2]] <- NULL)
@@ -1228,15 +1215,13 @@ test_that("[[<-.Idf and $<-.Idf", {
     expect_silent(without_checking(idf_1[["BuildingSurface:Detailed"]] <- NULL))
     expect_silent(without_checking(idf_1[["BuildingSurface:Detailed"]] <- idf_2[["BuildingSurface:Detailed"]]))
 
-    expect_is(with_option(list(autocomplete = TRUE), idf <- read_idf(example())), "Idf")
+    expect_is(idf <- read_idf(example()), "Idf")
 
     expect_error(idf$SimulationControl <- idf$Timestep)
     expect_error(idf$SimulationControl <- "Timestep, 6;\n")
     expect_error(idf$SimulationControl <- FALSE)
 
     # UNIQUE-OBJECT CLASS {{{
-    expect_true("SimulationControl" %in% names(idf))
-
     expect_silent(idf$Material_NoMass$R13LAYER$Thermal_Absorptance <- 0.5)
     expect_equal(idf$Material_NoMass$R13LAYER$Thermal_Absorptance, 0.5)
     expect_silent(idf$Material_NoMass$R13LAYER[["Thermal Absorptance"]] <- 0.6)
@@ -1264,18 +1249,15 @@ test_that("[[<-.Idf and $<-.Idf", {
     expect_null(without_checking(idf$SimulationControl <- NULL))
     expect_false(idf$is_valid_class("SimulationControl"))
     expect_null(idf$SimulationControl)
-    expect_false({capture.output(with_option(list(autocomplete = TRUE), print(idf))); "SimulationControl" %in% names(idf)})
 
     # can insert unique-object class
-    expect_silent(with_option(list(autocomplete = TRUE), idf$SimulationControl <- tbl))
+    expect_silent(idf$SimulationControl <- tbl)
+    expect_true(idf$is_valid_class("SimulationControl"))
+    expect_silent(idf$SimulationControl <- str)
     expect_true(idf$is_valid_class("SimulationControl"))
-    expect_silent(with_option(list(autocomplete = TRUE), idf$SimulationControl <- str))
-    expect_true("SimulationControl" %in% names(idf))
     # }}}
 
     # NORMAL CLASS {{{
-    expect_true("Material" %in% names(idf))
-
     # get data.frame input
     tbl <- idf$to_table(class = "Material")
     tbl[3, value := "0.2"]
@@ -1294,16 +1276,12 @@ test_that("[[<-.Idf and $<-.Idf", {
     expect_silent(idf$Material <- NULL)
     expect_false(idf$is_valid_class("Material"))
     expect_null(idf$Material)
-    # TODO: dynamically modify active bindings
-    # expect_false("Material" %in% names(idf))
 
     # can insert class
     expect_silent(idf$Material <- tbl)
     expect_true(idf$is_valid_class("Material"))
     expect_silent(idf$Material <- NULL)
     expect_silent(idf$Material <- str)
-    # TODO: dynamically modify active bindings
-    # expect_true("Material" %in% names(idf))
     eplusr_option(validate_level = "final")
 
     # can directly insert objects from other idf
